{ pkgs, ... }:
{
  imports = [
    ./fs.nix
  ];

  colinsane.gui.sway.enable = true;
  colinsane.impermanence.enable = true;
  boot.loader.generic-extlinux-compatible.enable = true;
  boot.loader.efi.canTouchEfiVariables = false;
  colinsane.image.extraBootFiles = [ pkgs.bootpart-uefi-x86_64 ];

  hardware.opengl.extraPackages = with pkgs; [
    intel-compute-runtime
    intel-media-driver  # new
    libvdpau-va-gl      # new
    vaapiIntel
  ];

  # default config: https://man.archlinux.org/man/snapper-configs.5
  # defaults to something like:
  #   - hourly snapshots
  #   - auto cleanup; keep the last 10 hourlies, last 10 daylies, last 10 monthlys.
  services.snapper.configs.nix = {
    # TODO: for the impermanent setup, we'd prefer to just do /nix/persist,
    # but that also requires setting up the persist dir as a subvol
    subvolume = "/nix";
  };

  # TODO: only here for debugging
  # services.ipfs.enable = true;

  # docs: https://nixos.org/manual/nixos/stable/options.html#opt-system.stateVersion
  system.stateVersion = "21.05";
}
